<?php
/**
 * Contextual Help
 *
 * @package     KBS
 * @subpackage  Admin/Customers
 * @copyright   Copyright (c) 2017, Mike Howard
 * @license     http://opensource.org/licenses/gpl-2.0.php GNU Public License
 * @since       1.0
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) )
	exit;

/**
 * Customers contextual help.
 *
 * @since       1.0
 * @return      void
 */
function kbs_customers_contextual_help() {
	$screen = get_current_screen();

	if ( 'kbs_ticket_page_kbs-customers' != $screen->id || ! isset( $_GET['view'] ) )	{
		return;
	}

	$article_singular = kbs_get_article_label_singular();
	$article_plural   = kbs_get_article_label_plural();
	$ticket_singular  = kbs_get_ticket_label_singular();
	$ticket_plural    = kbs_get_ticket_label_plural();

	$screen->set_help_sidebar( kbs_get_contextual_help_sidebar_text() );

	if ( 'add' == $_GET['view'] )	{

        do_action( 'kbs_customer_before_add_contextual_help', $screen );
		$screen->add_help_tab( array(
			'id'      => 'kbs-customer-add',
			'title'   => esc_html__( 'Add Customer', 'kb-support' ),
			'content' => apply_filters( 'kbs_customer_add_contextual_help',
				'<p>' . wp_kses_post( __( 'To add a new customer, simply enter their name and email address before clicking <em>Add Customer</em>.', 'kb-support' ) ) . '</p>'
            )
		) );

	} else	{

        do_action( 'kbs_customer_before_profile_contextual_help', $screen );
		$screen->add_help_tab( array(
			'id'      => 'kbs-customer-profile',
			'title'   => esc_html__( 'Customer Profile', 'kb-support' ),
			'content' => apply_filters( 'kbs_customer_profile_contextual_help',
				'<p>' . esc_html__( 'You can view and edit your customers profile here.', 'kb-support' ) . '</p>' .
				'<p>' . wp_kses_post( __( 'Click on the <em>Edit Customer</em> link to reveal a number of input fields that you can complete to fill the customer profile. You can also attach the customer account to a WordPress user account that is already registered on your website by entering the relevant username where specified.', 'kb-support' ) ) . '</p>' .
				'<p>' . sprintf(
					wp_kses_post( __( '<strong>Customer Emails</strong> - All of the customers associated email addresses are displayed within this table. Adding additional email addresses for the customer will enable them to log %1$s with any of their associated email addresses, and have the %2$s still associated to their account. Use the relevant action links to remove additional email addresses or set them as the customers primary address.', 'kb-support' ) ),
					strtolower( $ticket_plural ),
					strtolower( $ticket_singular )
				) . '</p>' .
				'<p>' . sprintf(
					wp_kses_post( __( '<strong>Recent %1$s</strong> - An overview of all the customers %2$s are displayed here.', 'kb-support' ) ),
					$ticket_plural,
					strtolower( $ticket_plural )
				) . '</p>'
            )
		) );

        do_action( 'kbs_customer_before_notes_contextual_help', $screen );
		$screen->add_help_tab( array(
			'id'      => 'kbs-customer-notes',
			'title'   => esc_html__( 'Customer Notes', 'kb-support' ),
			'content' => apply_filters( 'kbs_customer_notes_contextual_help',
				'<p>' . esc_html__( 'Enter notes regarding your customer here. These notes are not visible to the customers themselves.', 'kb-support' ) . '</p>' .
				'<p>' . esc_html__( 'Under the textarea that enables you to add a new note, existing notes are displayed.', 'kb-support' )  . '</p>'
            )
		) );

        do_action( 'kbs_customer_before_delete_contextual_help', $screen );
		$screen->add_help_tab( array(
			'id'      => 'kbs-customer-delete',
			'title'   => esc_html__( 'Delete Customer', 'kb-support' ),
			'content' => apply_filters( 'kbs_customer_delete_contextual_help',
				'<p>' . esc_html__( 'This tab enables you to delete a customer from the database.', 'kb-support' ) . '</p>' .
				'<p>' . wp_kses_post( __( 'To proceed select the <em>Are you sure you want to delete this customer?</em> checkbox to enable the <em>Delete Customer</em> button. Click the button to delete the customer.', 'kb-support' ) ) . '</p>'
            )
		) );

	}
	do_action( 'kbs_customers_contextual_help' );

} // kbs_customers_contextual_help
add_action( 'load-kbs_ticket_page_kbs-customers', 'kbs_customers_contextual_help' );
